@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Compatibility Plugin
-  * Copyright (C) 2004-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Copyright (C) 2004-2005 Paul Lesneiwski <paul@openguild.net>
   * This program is licensed under GPL. See COPYING for details
   *
   */
@@ -173,22 +173,118 @@
 
 
 
+/**
+  * Load configuration file
+  *
+  * Convenience function for plugins that loads a configuration
+  * file (or files).  If the file(s) is(are) not found, an error
+  * is displayed and execution stops (function won't return).  
+  * If multiple configuration files are given, ALL of them are 
+  * included, if they exist, in the order given.  Only one of 
+  * them needs to be found to avert triggering an error.
+  *
+  * Non-functional on login_before hook.
+  *
+  * @param string $plugin_name The name of the plugin as
+  * it is known to SquirrelMail, that is, it is the name
+  * of the plugin directory
+  *
+  * @param array $config_files An array of files that will
+  * be included IN THE ORDER that they are given in the
+  * array.  Files should be specified relative to the calling
+  * plugin's directory, such as:
+  * array('config.php') or array('data/config.php', 'data/admins.php')
+  * It is also possible to give a full/direct path to a 
+  * configuration file by placing a forward slash at the 
+  * beginning of the file:
+  * array('/var/lib/squirrelmail/config/myplugin.conf')
+  *
+  */
+function load_config($plugin_name, $config_files)
+{
+
+   global $compatibility_sm_path;
+
+
+   // if only one config file given as string, push 
+   // into an array just to be nice
+   //
+   if (!is_array($config_files)) $config_files = array($config_files);
+      
+
+   // loop through files, attempting to include them
+   // 
+   $file_count = 1;
+   foreach ($config_files as $file)
+   {
+
+      if (strpos($file, '/') === 0)
+         $plugin_path = $file;
+      else 
+         $plugin_path = $compatibility_sm_path . 'plugins/' . $plugin_name . '/' . $file;
+
+      // store inclusion results to be checked below
+      //
+      ${'config' . $file_count} = @include_once($plugin_path);
+
+      $file_count++;
+      
+   }
+
+
+   // now check to see if we got at least one successful inclusion
+   //
+   $success = FALSE;
+   for ($i = 1; $i < $file_count; $i++)
+      if (${'config' . $i})
+      {
+         $success = TRUE;
+         break;
+      }
+
+
+   // error...
+   //
+   if (!$success)
+   {
+      global $color;
+      bindtextdomain ('compatibility', SM_PATH . 'locale');
+      textdomain ('compatibility');
+      $error_msg = _("Administrative error:") . '<br />' 
+                 . sprintf(_("The plugin %s has not been set up correctly."),
+                           '&quot;<b>' . $plugin_name . '</b>&quot;') 
+                 . '<br />' 
+                 . _("Please read the README or INSTALL files that came with the plugin.");
+      bindtextdomain ('squirrelmail', SM_PATH . 'locale');
+      textdomain ('squirrelmail');
+      plain_error_message($error_msg, $color);
+      exit;
+   }
+
+}
+
+
+
 /**
   * Validate Plugin Setup Utility
   *
-  * checks a plugin to see if the user has installed it 
+  * Checks a plugin to see if the user has installed it 
   * correctly by checking for the existence of the given
   * files (all relative from the plugin's directory)
   *
-  * $pluginName should be the name of the plugin as it is
-  * known to SquirrelMail, that is, it is the name of the
-  * plugin directory
+  * @param string $pluginName The name of the plugin as
+  * it is known to SquirrelMail, that is, it is the name
+  * of the plugin directory.
   *
-  * $configFiles should be an array of any files that the
+  * @param array $configFiles An array of any files that the
   * user should have set up for this plugin, for example:
   * array('config.php') or array('data/config.php', 'data/admins.php')
   * where all files will be referenced from the plugin's
-  * main directory
+  * main directory.
+  * It is also possible to give a full/direct path to a 
+  * configuration file by placing a forward slash at the 
+  * beginning of the file:
+  * array('/var/lib/squirrelmail/config/myplugin.conf')
   *
   */
 function check_plugin_setup($pluginName, $configFiles)
@@ -206,18 +302,28 @@ function check_plugin_setup($pluginName, $configFiles)
    foreach ($configFiles as $configFile)
    {
 
-      if (!file_exists($compatibility_sm_path . 'plugins/' . $pluginName . '/' . $configFile))
+      if (strpos($configFile, '/') === 0)
+         $plugin_path = $configFile;
+      else 
+         $plugin_path = $compatibility_sm_path . 'plugins/' . $pluginName . '/' . $configFile;
+
+      if (!file_exists($plugin_path))
       {
 
          global $color;
          bindtextdomain ('compatibility', SM_PATH . 'locale');
          textdomain ('compatibility');
-         plain_error_message(_("Administrative error:") . '<br />' 
-            . sprintf(_("The plugin %s has not been set up correctly."),
-                '&quot;<b>' . $pluginName . '</b>&quot;') . '<br />' 
-            . sprintf(_("The configuration file %s is missing."),
-               '&quot;<b>' . $configFile . '</b>&quot;') . '<br />'
-            . _("Please read the README or INSTALL files that came with the plugin."), $color);
+         $error_msg = _("Administrative error:") . '<br />' 
+                    . sprintf(_("The plugin %s has not been set up correctly."),
+                              '&quot;<b>' . $pluginName . '</b>&quot;') 
+                    . '<br />' 
+                    . sprintf(_("The file %s is missing."),
+                              '&quot;<b>' . $configFile . '</b>&quot;') 
+                    . '<br />'
+                    . _("Please read the README or INSTALL files that came with the plugin.");
+         bindtextdomain ('squirrelmail', SM_PATH . 'locale');
+         textdomain ('squirrelmail');
+         plain_error_message($error_msg, $color);
          exit;
 
       }
@@ -226,4 +332,6 @@ function check_plugin_setup($pluginName, $configFiles)
 
 }
 
+
+
 ?>
